@@ -1,10 +1,6 @@
 import logging
 
-from django.contrib.gis.db.backends.postgis.base import \
-    DatabaseWrapper as PostgisDBWrapper
-
 from django.db import ProgrammingError
-from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 
 from . import base_impl
